@@ -4,6 +4,7 @@ from urllib3.util.retry import Retry
 import random
 import logging
 import requests
+import pandas as pd
 
 ops = {
     '<': operator.lt,
@@ -60,15 +61,19 @@ def add_random_synonymous_to_sentence(phrase, placeholder, synonyms):
     return phrase
 
 
-def nlg(json, examples, example_sentences, example_records, max_tokens=64):
+def nlg(df, examples, example_sentences, max_tokens=64):
+    # The parameter "df" is a dataframe, but it will be converted into a dict, and called df in each case
+
     headers = {
         "Content-Type": "application/json"
     }
+
+    dict_df = df.to_dict()
+
     data = {
-        "json_db": json,
+        "df": dict_df,
         "examples": examples,
         "examples_sentences": example_sentences,
-        "example_of_records": example_records,
         "max_tokens": max_tokens
     }
 
@@ -83,14 +88,7 @@ def nlg(json, examples, example_sentences, example_records, max_tokens=64):
     r.raise_for_status()
 
     try:
-        return r.json()['nlp_list']
+        df_response = pd.DataFrame.from_dict(r.json()['dict_df'])
+        return df_response
     except:
         logging.error(r.json())
-
-    # result = requests.post(url, data=data)
-    # if result.ok:
-    #     vec = json.loads(result.text)
-    #     return vec
-    # else:
-    #     error = "Error: somenthing went wrong!"
-    #     return error
