@@ -64,7 +64,7 @@ class AskdataPandasExtension:
         self.r1 = r1
 
 
-    def to_dataset(self, workspace:str, replace=False, dataset_name=""):
+    def save_dataset(self, workspace:str, replace=False, dataset_name=""):
 
         if self._env.lower() == 'dev':
             askdata_url = url_list['BASE_URL_ASKDATA_DEV']
